====================================
Benchmarks for Hydrologic Timeseries
====================================

.. image:: https://github.com/wknoben/hydrobm/actions/workflows/testing.yml/badge.svg
   :target: https://github.com/wknoben/hydrobm/actions/workflows/testing.yml


.. image:: https://img.shields.io/pypi/v/hydrobm.svg
        :target: https://pypi.python.org/pypi/hydrobm


Python package for calculating simple benchmarks from hydroclimatic timeseries.

* Free software: GNU General Public License v3.
* Documentation: https://hydrobm.readthedocs.io/en/latest/.

Features
--------

* Works with netcdf and .csv files, through `xarray` and `pandas` respectively.
* Calculates simple benchmarks models for streamflow timeseries, such as the long-term mean, seasonal cycle and basic representations of the rainfall-runoff relationship.
* Capability to run a basic snow accumulation and melt model.


Provenance
----------
Build with `Scientific Python Cookiecutter <https://nsls-ii.github.io/scientific-python-cookiecutter/index.html>`_.
